pub struct W(/* private fields */);Expand description
Register PWRCTRL writer
Implementations
Sourceimpl W
impl W
Sourcepub fn ppu_access_unlock(&mut self) -> PPU_ACCESS_UNLOCK_W<'_, 0>
pub fn ppu_access_unlock(&mut self) -> PPU_ACCESS_UNLOCK_W<'_, 0>
Bit 0 - PPU_ACCESS_FILTER write unlock. When 1, Both PPU_ACCESS_FILTER and this register bits can be written. When set to ‘0’ the PPU_ACCESS_FILTER and this register bit will no longer writable, and PPU_ACCESS_UNLOCK will stay ‘0’.
Sourcepub fn ppu_access_filter(&mut self) -> PPU_ACCESS_FILTER_W<'_, 1>
pub fn ppu_access_filter(&mut self) -> PPU_ACCESS_FILTER_W<'_, 1>
Bit 1 - Filter Access to PPU Registers. When set to ‘1’ only key PPU interrupt handling registers are open to write access, and all other PPU registers are read only. When set to ‘0’ releases all PPU register to full access.
Methods from Deref<Target = W<PWRCTRL_SPEC>>